IntelMQ Manager

#### Sign in

Username
Password

### Configuration

To either change the currently deployed configuration or to create a new one in a graphical fashion.

### Management

This is where you go to start/stop your bots or check on their status.

### Monitor

This feature is meant to allow you to check on the overall status of your botnet. You can read the bot logs, see how the queues are behaving and other features that allow you to have a better overview of the overall health of the system.

### Check

Check IntelMQ is running properly.

### About

To learn more about the project's goals and contributors.

?>